==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta2HorizontalPodAutoscalerStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import org.joda.time.DateTime;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface V2beta2HorizontalPodAutoscalerStatusFluent<A extends V2beta2HorizontalPodAutoscalerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V2beta2HorizontalPodAutoscalerCondition item);
    public A setToConditions(int index,V2beta2HorizontalPodAutoscalerCondition item);
    public A addToConditions(V2beta2HorizontalPodAutoscalerCondition... items);
    public A addAllToConditions(Collection<V2beta2HorizontalPodAutoscalerCondition> items);
    public A removeFromConditions(V2beta2HorizontalPodAutoscalerCondition... items);
    public A removeAllFromConditions(Collection<V2beta2HorizontalPodAutoscalerCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta2HorizontalPodAutoscalerCondition> getConditions();
    public List<V2beta2HorizontalPodAutoscalerCondition> buildConditions();
    public V2beta2HorizontalPodAutoscalerCondition buildCondition(int index);
    public V2beta2HorizontalPodAutoscalerCondition buildFirstCondition();
    public V2beta2HorizontalPodAutoscalerCondition buildLastCondition();
    public V2beta2HorizontalPodAutoscalerCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta2HorizontalPodAutoscalerConditionBuilder> predicate);
    public A withConditions(List<V2beta2HorizontalPodAutoscalerCondition> conditions);
    public A withConditions(V2beta2HorizontalPodAutoscalerCondition... conditions);
    public Boolean hasConditions();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewCondition();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewConditionLike(V2beta2HorizontalPodAutoscalerCondition item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V2beta2HorizontalPodAutoscalerCondition item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editCondition(int index);
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editFirstCondition();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editLastCondition();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta2HorizontalPodAutoscalerConditionBuilder> predicate);
    public A addToCurrentMetrics(int index,V2beta2MetricStatus item);
    public A setToCurrentMetrics(int index,V2beta2MetricStatus item);
    public A addToCurrentMetrics(V2beta2MetricStatus... items);
    public A addAllToCurrentMetrics(Collection<V2beta2MetricStatus> items);
    public A removeFromCurrentMetrics(V2beta2MetricStatus... items);
    public A removeAllFromCurrentMetrics(Collection<V2beta2MetricStatus> items);
    
/**
 * This method has been deprecated, please use method buildCurrentMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta2MetricStatus> getCurrentMetrics();
    public List<V2beta2MetricStatus> buildCurrentMetrics();
    public V2beta2MetricStatus buildCurrentMetric(int index);
    public V2beta2MetricStatus buildFirstCurrentMetric();
    public V2beta2MetricStatus buildLastCurrentMetric();
    public V2beta2MetricStatus buildMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricStatusBuilder> predicate);
    public A withCurrentMetrics(List<V2beta2MetricStatus> currentMetrics);
    public A withCurrentMetrics(V2beta2MetricStatus... currentMetrics);
    public Boolean hasCurrentMetrics();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetric();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetricLike(V2beta2MetricStatus item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> setNewCurrentMetricLike(int index,V2beta2MetricStatus item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editCurrentMetric(int index);
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editFirstCurrentMetric();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editLastCurrentMetric();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricStatusBuilder> predicate);
    public Integer getCurrentReplicas();
    public A withCurrentReplicas(Integer currentReplicas);
    public Boolean hasCurrentReplicas();
    public A withNewCurrentReplicas(int arg1);
    public A withNewCurrentReplicas(String arg1);
    public Integer getDesiredReplicas();
    public A withDesiredReplicas(Integer desiredReplicas);
    public Boolean hasDesiredReplicas();
    public A withNewDesiredReplicas(int arg1);
    public A withNewDesiredReplicas(String arg1);
    public DateTime getLastScaleTime();
    public A withLastScaleTime(DateTime lastScaleTime);
    public Boolean hasLastScaleTime();
    public A withNewLastScaleTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewLastScaleTime(long arg0);
    public A withNewLastScaleTime(Object arg0);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(String arg1);
    public A withNewObservedGeneration(long arg1);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2HorizontalPodAutoscalerConditionFluent<V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface CurrentMetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2MetricStatusFluent<V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<N>>{

        
    public N and();    public N endCurrentMetric();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta2HorizontalPodAutoscalerStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import org.joda.time.DateTime;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface V2beta2HorizontalPodAutoscalerStatusFluent<A extends V2beta2HorizontalPodAutoscalerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V2beta2HorizontalPodAutoscalerCondition item);
    public A setToConditions(int index,V2beta2HorizontalPodAutoscalerCondition item);
    public A addToConditions(V2beta2HorizontalPodAutoscalerCondition... items);
    public A addAllToConditions(Collection<V2beta2HorizontalPodAutoscalerCondition> items);
    public A removeFromConditions(V2beta2HorizontalPodAutoscalerCondition... items);
    public A removeAllFromConditions(Collection<V2beta2HorizontalPodAutoscalerCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta2HorizontalPodAutoscalerCondition> getConditions();
    public List<V2beta2HorizontalPodAutoscalerCondition> buildConditions();
    public V2beta2HorizontalPodAutoscalerCondition buildCondition(int index);
    public V2beta2HorizontalPodAutoscalerCondition buildFirstCondition();
    public V2beta2HorizontalPodAutoscalerCondition buildLastCondition();
    public V2beta2HorizontalPodAutoscalerCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta2HorizontalPodAutoscalerConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta2HorizontalPodAutoscalerConditionBuilder> predicate);
    public A withConditions(List<V2beta2HorizontalPodAutoscalerCondition> conditions);
    public A withConditions(V2beta2HorizontalPodAutoscalerCondition... conditions);
    public Boolean hasConditions();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewCondition();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewConditionLike(V2beta2HorizontalPodAutoscalerCondition item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V2beta2HorizontalPodAutoscalerCondition item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editCondition(int index);
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editFirstCondition();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editLastCondition();
    public V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta2HorizontalPodAutoscalerConditionBuilder> predicate);
    public A addToCurrentMetrics(int index,V2beta2MetricStatus item);
    public A setToCurrentMetrics(int index,V2beta2MetricStatus item);
    public A addToCurrentMetrics(V2beta2MetricStatus... items);
    public A addAllToCurrentMetrics(Collection<V2beta2MetricStatus> items);
    public A removeFromCurrentMetrics(V2beta2MetricStatus... items);
    public A removeAllFromCurrentMetrics(Collection<V2beta2MetricStatus> items);
    
/**
 * This method has been deprecated, please use method buildCurrentMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta2MetricStatus> getCurrentMetrics();
    public List<V2beta2MetricStatus> buildCurrentMetrics();
    public V2beta2MetricStatus buildCurrentMetric(int index);
    public V2beta2MetricStatus buildFirstCurrentMetric();
    public V2beta2MetricStatus buildLastCurrentMetric();
    public V2beta2MetricStatus buildMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricStatusBuilder> predicate);
    public Boolean hasMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricStatusBuilder> predicate);
    public A withCurrentMetrics(List<V2beta2MetricStatus> currentMetrics);
    public A withCurrentMetrics(V2beta2MetricStatus... currentMetrics);
    public Boolean hasCurrentMetrics();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetric();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetricLike(V2beta2MetricStatus item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> setNewCurrentMetricLike(int index,V2beta2MetricStatus item);
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editCurrentMetric(int index);
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editFirstCurrentMetric();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editLastCurrentMetric();
    public V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricStatusBuilder> predicate);
    public Integer getCurrentReplicas();
    public A withCurrentReplicas(Integer currentReplicas);
    public Boolean hasCurrentReplicas();
    public Integer getDesiredReplicas();
    public A withDesiredReplicas(Integer desiredReplicas);
    public Boolean hasDesiredReplicas();
    public DateTime getLastScaleTime();
    public A withLastScaleTime(DateTime lastScaleTime);
    public Boolean hasLastScaleTime();
    public A withNewLastScaleTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewLastScaleTime(Object arg0);
    public A withNewLastScaleTime(long arg0);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2HorizontalPodAutoscalerConditionFluent<V2beta2HorizontalPodAutoscalerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface CurrentMetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2MetricStatusFluent<V2beta2HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<N>>{

        
    public N and();    public N endCurrentMetric();
}


}
